GeoMeshPy

A Python package that converts vertices coming from geo modelling tools like GemPy. This package can be linked with the new functionality of GMSH for
creating meshes that match the geometry of your geological model.
The superiority is that this precedure can be achieved without manual treatement of the mesh. At the end, the automated coversion allows for making
water tight meshes matching the primary geometry.
